==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCli.md <==
# AmazonElasticContainerServiceCopilotCli


```text
aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCli
```

```text
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCli')
```



| Illustration | AmazonElasticContainerServiceCopilotCli | AmazonElasticContainerServiceCopilotCliCard | AmazonElasticContainerServiceCopilotCliGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCli.png) | ![illustration for AmazonElasticContainerServiceCopilotCli](../../../aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCli.Local.png) | ![illustration for AmazonElasticContainerServiceCopilotCliCard](../../../aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCliCard.Local.png) | ![illustration for AmazonElasticContainerServiceCopilotCliGroup](../../../aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCliGroup.Local.png) |




## AmazonElasticContainerServiceCopilotCli

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceCopilotCli
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCli')

' renders the element
AmazonElasticContainerServiceCopilotCli('AmazonElasticContainerServiceCopilotCli', 'Amazon Elastic Container Service Copilot Cli', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceCopilotCli
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCli')

' renders the element
AmazonElasticContainerServiceCopilotCli('AmazonElasticContainerServiceCopilotCli', 'Amazon Elastic Container Service Copilot Cli', 'an optional tech label')
@enduml
```

## AmazonElasticContainerServiceCopilotCliCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceCopilotCliCard
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCli')

' renders the element
AmazonElasticContainerServiceCopilotCliCard('AmazonElasticContainerServiceCopilotCliCard', 'Amazon Elastic Container Service Copilot Cli Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceCopilotCliCard
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCli')

' renders the element
AmazonElasticContainerServiceCopilotCliCard('AmazonElasticContainerServiceCopilotCliCard', 'Amazon Elastic Container Service Copilot Cli Card', 'an optional description')
@enduml
```

## AmazonElasticContainerServiceCopilotCliGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceCopilotCliGroup
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCli')

' renders the element
AmazonElasticContainerServiceCopilotCliGroup('AmazonElasticContainerServiceCopilotCliGroup', 'Amazon Elastic Container Service Copilot Cli Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceCopilotCliGroup
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCli')

' renders the element
AmazonElasticContainerServiceCopilotCliGroup('AmazonElasticContainerServiceCopilotCliGroup', 'Amazon Elastic Container Service Copilot Cli Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCli.md <==
# AmazonElasticContainerServiceCopilotCli


```text
aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCli
```

```text
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCli')
```



| Illustration | AmazonElasticContainerServiceCopilotCli | AmazonElasticContainerServiceCopilotCliCard | AmazonElasticContainerServiceCopilotCliGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCli.png) | ![illustration for AmazonElasticContainerServiceCopilotCli](../../../aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCli.Local.png) | ![illustration for AmazonElasticContainerServiceCopilotCliCard](../../../aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCliCard.Local.png) | ![illustration for AmazonElasticContainerServiceCopilotCliGroup](../../../aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCliGroup.Local.png) |




## AmazonElasticContainerServiceCopilotCli

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceCopilotCli
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCli')

' renders the element
AmazonElasticContainerServiceCopilotCli('AmazonElasticContainerServiceCopilotCli', 'Amazon Elastic Container Service Copilot Cli', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceCopilotCli
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCli')

' renders the element
AmazonElasticContainerServiceCopilotCli('AmazonElasticContainerServiceCopilotCli', 'Amazon Elastic Container Service Copilot Cli', 'an optional tech label')
@enduml
```

## AmazonElasticContainerServiceCopilotCliCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceCopilotCliCard
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCli')

' renders the element
AmazonElasticContainerServiceCopilotCliCard('AmazonElasticContainerServiceCopilotCliCard', 'Amazon Elastic Container Service Copilot Cli Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceCopilotCliCard
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCli')

' renders the element
AmazonElasticContainerServiceCopilotCliCard('AmazonElasticContainerServiceCopilotCliCard', 'Amazon Elastic Container Service Copilot Cli Card', 'an optional description')
@enduml
```

## AmazonElasticContainerServiceCopilotCliGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceCopilotCliGroup
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCli')

' renders the element
AmazonElasticContainerServiceCopilotCliGroup('AmazonElasticContainerServiceCopilotCliGroup', 'Amazon Elastic Container Service Copilot Cli Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerServiceCopilotCliGroup
include('aws-20210730/Resource/Containers/AmazonElasticContainerServiceCopilotCli')

' renders the element
AmazonElasticContainerServiceCopilotCliGroup('AmazonElasticContainerServiceCopilotCliGroup', 'Amazon Elastic Container Service Copilot Cli Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
